package cn.com.ctop.kuaishou.modules.batch.mapper;

import cn.com.ctop.kuaishou.modules.batch.entity.KuaishouSupplyChain;

import cn.com.ctop.kuaishou.modules.batch.entity.KuaishouSupplyChainSettlement;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 快手电商-供应链订单信息
 * @author jeecg-boot
 * 2022-12-01
 * @version V1.0
 */
public interface KuaishouSupplyChainMapper extends BaseMapper<KuaishouSupplyChain> {

    List<JSONObject>  getCookie();


    List<JSONObject> getDataList(@Param("statDate") Long statDate);

    List<JSONObject> getPromoterDataList(@Param("statDate") Long statDate);

    void deletePromoterBindChannelByDate(@Param("date") Long date);

    void cleanKuaiShouPromoterBindChannel(@Param("date") Long date);

    List<JSONObject> getSamplesData(@Param("startDate") String startDate);

    void cleanBytedancePromoterBindChannel(@Param("date") Long date);

    void deleteMgsPromoterBindChannelByDate(@Param("date") Long date);

    void cleanMgsKuaiShouPromoterBindChannel(@Param("date") Long date);

    List<JSONObject> getMgsDataList(@Param("statDate") Long statDate);

    List<JSONObject> getRocketDataList(Long statDate);

    void deleteRocketPromoterBindChannelByDate(@Param("date") Long date);

    void cleanRocketKuaiShouPromoterBindChannel(@Param("date") Long date);

    void replaceRuiXuanCcr(@Param("adds") List<JSONObject> adds);

    void replaceMiaoGouSICcr(@Param("adds") List<JSONObject> adds);

    void replaceRocketCcr(@Param("adds") List<JSONObject> adds);

    List<JSONObject> getMgsCookie();

    List<JSONObject> getRocketCookie();

    List<JSONObject> getYuFuCiikie();

    List<JSONObject> getYufuDataList(@Param("statDate") Long statDate);

    void deleteYufuPromoterBindChannelByDate(@Param("date") Long date);

    void cleanYufuKuaiShouPromoterBindChannel(@Param("date") Long date);

    void replaceYUfuCcr(@Param("adds") List<JSONObject> adds);

    List<String> getActivityKeyWord(@Param("date") String date, @Param("db") String db);

    void replaceRuiXuanSellerInfo(@Param("adds") List<JSONObject> adds);

    void replaceMiaogousiSellerInfo(@Param("adds") List<JSONObject> adds);

    void replaceRocketSellerInfo(@Param("adds") List<JSONObject> adds);

    void replaceYUfuSellerInfo(@Param("adds") List<JSONObject> adds);

    void deleteItemBindCourtshipByDate(@Param("date") Long date);

    void cleanKuaiShouItemBindCourtship(@Param("date") Long date);

    void cleanBytedanceItemBindCourtship(@Param("date") Long date);

    void deleteMgsItemBindCourtshipByDate(@Param("date") Long date);

    void cleanMgsItemBindCourtship(@Param("date") Long date);

    void deleteRocketItemBindCourtshipByDate(@Param("date") Long date);

    void cleanRocketItemBindCourtship(@Param("date") Long date);

    void deleteYufuItemBindCourtshipByDate(@Param("date") Long date);

    void cleanYufuItemBindCourtship(@Param("date") Long date);

    void replaceRuixuanSupplyChains(@Param("adds") List<KuaishouSupplyChain> ruixuanSupplyChains);

    void replaceMgsSupplyChains(@Param("adds") List<KuaishouSupplyChain> mgsSupplyChains);

    void replaceRocketSupplyChains(@Param("adds") List<KuaishouSupplyChain> rocketSupplyChains);

    void replaceYufuSupplyChains(@Param("adds") List<KuaishouSupplyChain> yufuSupplyChains);

    void replaceYuXiuSupplyChains(@Param("adds") List<KuaishouSupplyChain> yuxiuSupplyChains);

    void deleteYuXiuPromoterBindChannelByDate(@Param("date") Long date);

    void cleanYuXiuKuaiShouPromoterBindChannel(@Param("date") Long date);

    void deleteYuXiuItemBindCourtshipByDate(@Param("date") Long date);

    void cleanYuXiuItemBindCourtship(@Param("date") Long date);

    void replaceZhiShuiSupplyChains(@Param("adds") List<KuaishouSupplyChain> zhiShuiSupplyChains);

    void deleteZhiShuiPromoterBindChannelByDate(@Param("date") Long date);

    void cleanZhiShuiKuaiShouPromoterBindChannel(@Param("date") Long date);

    void deleteZhiShuiItemBindCourtshipByDate(@Param("date") Long date);

    void cleanZhiShuiItemBindCourtship(@Param("date") Long date);

    void replaceYuXiuSellerInfo(@Param("adds") List<JSONObject> adds);

    void replaceZhishuiSellerInfo(@Param("adds") List<JSONObject> adds);

    List<JSONObject> getZhiShuiCiikie();

    List<JSONObject> getyuxiuCiikie();
}
